// =========================================================================================================
//
// Use this script to have a 3D-marker follow a unit (the marker will be created automatically)
//
// call syntax (when used in a unit's init line): x=[this] execVM "attachmarker.sqf"
// 			"this" is the current object/unit that should be followed
//
//      By default the short marker will be created, if you would like the tall one instead,
//      enter "LG" in the parameter list (e.g. x=[this,"LG"] execVM "attachmarker.sqf"
// 
//      By default the marker side is the same as that of the unit, but if you specific a side in the
//      parameter list, then that one will be taken instead (e.g. x=[this,civilian] execVM "attachmarker.sqf")
//      (Side options are west=green, east=red, resistance=blue & civilian=white)
// 
//  Upon death of the tracked unit the marker height will be lowered by half.
// 
// =========================================================================================================
// 
//      If you would like to indicate the knowledge another unit has about the marked one,
//      enter the other unit's name as the second parameter (e.g. x=[this,player] execVM "attachmarker.sqf")
//      The height of the marker will indicate the level of knowledge (4=highest)
// 
//      By default the marker is displayed at the location of the tracked unit (first parameter).
//      To display the marker at the location of the second unit, enter "SWAP" in the parameter list
//      (e.g. x=[this,player,"swap"] execVM "attachmarker.sqf")
// 
// =========================================================================================================

// how often the marker should be updated (in seconds)
_frequency = .2;

// =========================================================================================================

_unit=_this select 0;
_side=side _unit;
_markertype="Arrow";

_height=-2.9; _fact=.725;
if (((_this find "LG")!=-1) || ((_this find "lg")!=-1)) then {
	_markertype="Marker";
	_height=-99.9;
	_fact=24.975;
}; 
{if ((_this find _x)!=-1) then {_side=_x}} foreach [west,east,resistance,civilian];

_markername = format["KRON_3D%1_",_markertype];
switch (_side) do {
	case west: 
		{ _markername = _markername+"W" };
	case east: 
		{ _markername = _markername+"E" };
	case resistance: 
		{ _markername = _markername+"R" };
	case civilian: 
		{ _markername = _markername+"C" };
};

_chkknow=false;
_inq=0;
if ((count _this)>1) then {
	_inq = _this select 1;
	if (typename (_inq)=="object") then { _chkknow=true; };
};

_trackpos = _unit;
if (_chkknow && (((_this find "SWAP")!=-1) || ((_this find "swap")!=-1))) then {_trackpos=_inq};

_marker = _markername createVehicle getPos _trackpos;

_x=0;_y=0;_goon=true;
for [{}, {_goon}, {true}] do 
{
	_pos = getPos _trackpos;
	_x = _pos select 0;
	_y = _pos select 1;
	_z = 0;
	if (_chkknow) then {
		_z = _height+(_inq knowsAbout _unit)*_fact;
		//player sidechat format["%1,%2:%3",_inq,_unit,(_inq knowsAbout _unit)];
	} else {
		if (!alive _unit) then {_goon=false};
	};
	_marker setPos [_x,_y,_z];
	_marker setDir getDir _trackpos;
	_marker setDamage 0;
	sleep _frequency;
};

_marker setPos [_x, _y, _height+1];
